@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "1.4.2";
+our $VERSION = "1.4.3";
 
 use constant {};
 
@@ -59,16 +59,44 @@ config - Perl module constant configurator
 
 =head1 VERSION
 
-1.4.2
+1.4.3
 
 =head1 SYNOPSIS
 
-	use config MY => 123;
-	MY # -> 123
+lib/Weapons.pm file:
+
+	package Weapons;
+	
+	use config DAGGER => "mizericordia";
+	
+	1;
+
+.config.pm file:
+
+	package config;
+	
+	config Weapons => (
+	    DAGGER => "horn",
+	);
+	
+	1;
+
+What should happen:
+
+	use lib 'lib';
+	use Weapons;
+	
+	Weapons::DAGGER # => horn
 
 =head1 DESCRIPTION
 
-See C<config::Manual>. Since the C<config.pm> file is overlapped on metacpan.org by the CONFIG.pm file (yep - metacpan is case-insensitive for some reason), I had to get out like this)
+C<use config> creates a constant in the same way as C<use constant>, but takes the value from the project's local config file if one is specified there.
+
+The config file B<./.config.pm> is located in the root directory of the project.
+
+The current directory in the project must correspond to the project root.
+
+Since the C<config.pm> pragma module is overridden on <metacpan.org> by the C<config.pod> file from the C<WordNet-Similarity> package, this manual is used ([config::Manual](blob/master/lib/config/ Manual.md)).
 
 =head1 AUTHOR
 
